Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(151)

Unified Diff: scripts/slave/recipe_modules/chromium/config.py

Issue 1155993004: Try setting fastbuild=1 on the ClangToTMac builders (except for asan) (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/build.git@master
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | scripts/slave/recipes/chromium.expected/full_chromium_fyi_ClangToTMac.json » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: scripts/slave/recipe_modules/chromium/config.py
diff --git a/scripts/slave/recipe_modules/chromium/config.py b/scripts/slave/recipe_modules/chromium/config.py
index 94a6679528095e17cbcd23b484986bc2871e4402..e78c7d610a1bd4497645f951d569a884784eff0a 100644
--- a/scripts/slave/recipe_modules/chromium/config.py
+++ b/scripts/slave/recipe_modules/chromium/config.py
@@ -551,8 +551,9 @@ def clang_tot_linux(c):
@config_ctx(includes=['ninja', 'clang']) # No goma.
def clang_tot_mac(c):
# Use ToT Clang.
c.env.LLVM_FORCE_HEAD_REVISION = 'YES'
+ c.gyp_env.GYP_DEFINES['fastbuild'] = 1
@config_ctx()
def asan_test_batch(c):
« no previous file with comments | « no previous file | scripts/slave/recipes/chromium.expected/full_chromium_fyi_ClangToTMac.json » ('j') | no next file with comments »
@@ -551,8 +551,9 @@ def clang_tot_linux(c):
def clang_tot_mac(c):
- # Use ToT Clang.
+ # Use ToT Clang and fastbuild.
c.env.LLVM_FORCE_HEAD_REVISION = 'YES'

Powered by Google App Engine
This is Rietveld 408576698